import {
  LoadedConfigSelectors,
  LocalConfigOptions,
} from "@smithy/node-config-provider";
export declare const REGION_ENV_NAME = "AWS_REGION";
export declare const REGION_INI_NAME = "region";
export declare const NODE_REGION_CONFIG_OPTIONS: LoadedConfigSelectors<string>;
export declare const NODE_REGION_CONFIG_FILE_OPTIONS: LocalConfigOptions;
